*************************
JobDiary
*************************

a funny and easy to use job diary to trace your activities and export reports

Installation
========

You may install this package in two ways:

- Compile from code ::

    git clone https://github.com/fbarresi/JobDiary.git
    cd JobDiary
    python setup.py install

- Pypi ::

    pip install jobdiary

Usage
========

Just type in the console::

    jd --help

Thanks
========

This project depends on TinyDB_ and Huepy_.

.. _TinyDB: https://github.com/msiemens/tinydb
.. _Huepy: https://github.com/s0md3v/hue


Contribute
========

Whould you like to contribute to this project? YES, PLEASE!

Just fork this repository and submit your pull request.
